---
name: Feature
about: Create a report to help us improve
title: "[Feature] "
labels: feature, new
assignees: ''

---

**Describe the feature**
A clear and concise description of what the feature is.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Additional context**
Add any other context about the feature here.
